<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>ライブ環境を検出しました。変更したいシステムの root パーティションを選択してください (Linux パーティションのみ表示されます)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>サブメニューのないシンプルなメニュー構成を使用</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>フラットメニューを使用する（サブメニューなし）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>起動先</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>メニューを表示せずにすぐ起動する場合は「0」、そのまま待機する場合は「-1」に設定します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>メニューのタイムアウト</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>カーネルのパラメータ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>このオプションを有効にすると、grub の起動メニューから選択したエントリは、将来のブートの新規の既定として保存されます。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>直前の起動の選択の保存を有効にします</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>UEFI の起動オプションの管理</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>背景</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>テーマの有効化</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>スプラッシュ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>メッセージ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>非常に詳細に</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>詳細に（既定の設定）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>限定的な</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>ログの表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Still running</source>
        <translation>まだ実行中です</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation>プロセスはまだ実行中です。本当に中止しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Set timeout</source>
        <translation>タイムアウトの設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Timeout in seconds:</source>
        <translation>タイムアウトの秒数:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="435"/>
        <location filename="../mainwindow.cpp" line="1070"/>
        <source>Timeout: %1 seconds</source>
        <translation>タイムアウト: %1 秒</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <location filename="../mainwindow.cpp" line="1085"/>
        <source>Boot Next: %1</source>
        <translation>次回以降の既定の起動: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Removal confirmation</source>
        <translation>削除の確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>本当にこの起動のエントリーを削除しても良いのですか？
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Select EFI file</source>
        <translation>EFI ファイルの選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>EFI ファイル (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <location filename="../mainwindow.cpp" line="325"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="518"/>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>%1 のソース・マウントポイントが見つかりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Set name</source>
        <translation>名前の設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>UEFI メニューの項目名を入力します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>問題が発生したため、項目を追加できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Installing bootsplash, please wait</source>
        <translation>bootsplash をインストールしています。お待ちください</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Updating sources</source>
        <translation>ソースのアップデート中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Installing</source>
        <translation>インストール中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not install the bootsplash.</source>
        <translation>bootsplash をインストールできません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Boot Current: %1</source>
        <translation>現在の起動設定: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Cannot continue</source>
        <translation>続行できません</translation>
    </message>
    <message>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation type="vanished">何も選択されていないので、起動オプションを変更できません。終了します...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>Could not create a temporary folder</source>
        <translation>一時フォルダを作成できませんでした</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>chroot 環境を作成できず、起動オプションを変更できません。終了中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>問題が発生したので、起動順序を保存できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="795"/>
        <location filename="../mainwindow.cpp" line="1185"/>
        <source>Updating configuration, please wait</source>
        <translation>設定更新中なのでお待ちください</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>Updating initramfs...</source>
        <translation>initramfs 更新中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <location filename="../mainwindow.cpp" line="1197"/>
        <source>Updating grub...</source>
        <translation>grub 更新中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>Changes have been successfully applied.</source>
        <translation>変更は正しく適用されました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="874"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="899"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">概要</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="877"/>
        <source>Program for selecting common start-up choices</source>
        <translation>一般的なスタートアップを選択するためのプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">ライセンス</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">更新履歴</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">キャンセル</translation>
    </message>
    <message>
        <source>MX Boot Options</source>
        <translation type="vanished">MX 起動オプション</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Running in a Virtual Machine</source>
        <translation>仮想マシンで実行中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>現在のシステムは仮想マシンで動作しています。
Plymouth のブーツプラッシュは限られた方法でしか動作しませんし、テーマをプレビューすることもできません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="916"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth パッケージがインストールされていません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth のパッケージは現在インストールされていません。
このまま続行してインストールしますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>画像 (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1043"/>
        <source>Press any key to close</source>
        <translation>任意のキーを押せば閉じます</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Log not found</source>
        <translation>ログが見つかりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Could not find log at </source>
        <translation>ログが見つかりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1051"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>UEFI の起動エントリを編集</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Up/Down ボタン、または項目のドラッグ＆ドロップで起動順序を変更できます。
- 項目は起動順に表示します。
- 灰色になっている行は有効ではありません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <location filename="../mainwindow.cpp" line="1111"/>
        <source>Set ac&amp;tive</source>
        <translation>アクティブにする(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>&amp;Add entry</source>
        <translation>エントリの追加(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1060"/>
        <source>Boot &amp;next</source>
        <translation>次回の起動(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>Move &amp;down</source>
        <translation>下へ移動(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>&amp;Remove entry</source>
        <translation>エントリの削除(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1064"/>
        <source>Re&amp;set next</source>
        <translation>次回リセット(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1065"/>
        <source>Change &amp;timeout</source>
        <translation>タイムアウトの時間変更(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>Move &amp;up</source>
        <translation>上へ移動(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <location filename="../mainwindow.cpp" line="1085"/>
        <source>not set, will boot using list order</source>
        <translation>設定せず、リスト順に起動</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1108"/>
        <source>Set &amp;inactive</source>
        <translation>非アクティブにする(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1161"/>
        <source>Needs reboot</source>
        <translation>再起動が必要です</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1162"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth のインストール直後なので、プレビューを表示するには再起動が必要かもしれません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1218"/>
        <source>Click to select theme</source>
        <translation>クリックしてテーマを選択</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Program for selecting common start-up choices</source>
        <translation>一般的なスタートアップを選択するためのプログラム</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>rootとしてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザーとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="936"/>
        <source>Select image to display in bootloader</source>
        <translation>ブートローダに表示するイメージを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1228"/>
        <source>Select GRUB theme</source>
        <translation>GRUB のテーマ選択</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
</context>
</TS>
